==> isis-fish-4.3.1.1-sources.jar: fr/ifremer/isisfish/simulator/sensitivity/SensitivityException.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 Ifremer, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.simulator.sensitivity;

/**
 * Sensitivity Exception throw if calculator,
 * fail to answer (ex : R) or something else.
 *
 * @author chatellier
 * @version $Revision: 1.0 $
 * 
 * Last update : $Date: 26 févr. 2009 $
 * By : $Author: chatellier $
 */
public class SensitivityException extends Exception {

    /** serialVersionUID. */
    private static final long serialVersionUID = -713095428835197215L;

    /**
     * Constructor with message.
     * 
     * @param message message
     */
    public SensitivityException(String message) {
        super(message);
    }

    /**
     * Constructor with message and cause.
     * 
     * @param message message
     * @param cause exception cause
     */
    public SensitivityException(String message, Throwable cause) {
        super(message, cause);
    }
}

==> isis-fish-4.4.0.0-20150624.091503-1-sources.jar: fr/ifremer/isisfish/simulator/sensitivity/SensitivityException.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: SensitivityException.java 4156 2014-12-09 11:27:18Z echatellier $
 * $HeadURL: http://svn.codelutin.com/isis-fish/trunk/src/main/java/fr/ifremer/isisfish/simulator/sensitivity/SensitivityException.java $
 * %%
 * Copyright (C) 2009 - 2010 Ifremer, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.simulator.sensitivity;

/**
 * Sensitivity Exception throw if calculator,
 * fail to answer (ex : R) or something else.
 *
 * @author chatellier
 * @version $Revision: 4156 $
 * 
 * Last update : $Date: 2014-12-09 12:27:18 +0100 (mar., 09 déc. 2014) $
 * By : $Author: echatellier $
 */
public class SensitivityException extends Exception {

    /** serialVersionUID. */
    private static final long serialVersionUID = -713095428835197215L;

    /**
     * Constructor with message.
     * 
     * @param message message
     */
    public SensitivityException(String message) {
        super(message);
    }

    /**
     * Constructor with message and cause.
     * 
     * @param message message
     * @param cause exception cause
     */
    public SensitivityException(String message, Throwable cause) {
        super(message, cause);
    }
}
